import * as AWS from 'aws-sdk';
import { IamPolicyDocument } from './aws-segments/iam-policy';
import { Trace } from 'aws-sdk/clients/xray';
export interface GetXrayTracesConf {
    /**
     * start time to search for. If not specified will do a "last x min search"
     */
    startTime?: Date;
    /**
     * Time in minutes range to search. If startTime is not specified this will be used as a last X min search.
     * Defaults to: 60
     */
    timeRangeMinutes?: number;
}
/**
 * Fetch xray traces. Combines the two functions of getTraceSummaries and batchGetTraces including support for pagination.
 */
export declare function getXrayTraces(conf?: GetXrayTracesConf): Promise<Trace[]>;
/**
 * Maps that maps a resource to set of actions
 */
export declare type ResourceActionMap = Map<string, Set<string>>;
/**
 * Map which maps a function to the set of ResourceActionMap
 */
export declare type FunctionToActionsMap = Map<string, ResourceActionMap>;
/**
 * Parse an xray trace return the passed in functionMap
 * @param trace
 * @param functionMap will populate with the found results
 */
export declare function parseXrayTrace(trace: AWS.XRay.Trace, functionMap: FunctionToActionsMap): FunctionToActionsMap;
export declare function parseXrayTraces(traces: AWS.XRay.Trace[], functionMap: FunctionToActionsMap): FunctionToActionsMap;
export declare function getFunctionActionMapFromXray(conf?: GetXrayTracesConf): Promise<Map<string, Map<string, Set<string>>>>;
export declare function createIAMPolicyDoc(map: ResourceActionMap, functionArn: string): IamPolicyDocument;
/**
 *
 * @param conf
 * @return object mapping function arn to file name
 */
export declare function scanXrayAndSavePolicyDocs(conf?: GetXrayTracesConf): Promise<{
    [i: string]: string;
}>;
